@@ -45,6 +45,7 @@
 #include "nautilus-dbus-manager.h"
 #include "nautilus-directory-private.h"
 #include "nautilus-file.h"
+#include "nautilus-files-view.h"
 #include "nautilus-file-operations.h"
 #include "nautilus-file-undo-manager.h"
 #include "nautilus-file-utilities.h"
@@ -84,6 +85,8 @@ typedef struct
 
     NautilusTagManager *tag_manager;
     GCancellable *tag_manager_cancellable;
+
+    guint previewer_selection_id;
 } NautilusApplicationPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (NautilusApplication, nautilus_application, GTK_TYPE_APPLICATION);
@@ -1065,24 +1068,28 @@ nautilus_application_init (NautilusApplication *self)
         { "check", 'c', 0, G_OPTION_ARG_NONE, NULL,
           N_("Perform a quick set of self-check tests."), NULL },
 #endif
-        /* dummy, only for compatibility reasons */
-        { "browser", '\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, NULL,
-          NULL, NULL },
-        /* ditto */
-        { "geometry", 'g', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, NULL,
-          N_("Create the initial window with the given geometry."), N_("GEOMETRY") },
         { "version", '\0', 0, G_OPTION_ARG_NONE, NULL,
           N_("Show the version of the program."), NULL },
         { "new-window", 'w', 0, G_OPTION_ARG_NONE, NULL,
           N_("Always open a new window for browsing specified URIs"), NULL },
-        { "no-default-window", 'n', 0, G_OPTION_ARG_NONE, NULL,
-          N_("Only create windows for explicitly specified URIs."), NULL },
         { "quit", 'q', 0, G_OPTION_ARG_NONE, NULL,
           N_("Quit Nautilus."), NULL },
         { "select", 's', 0, G_OPTION_ARG_NONE, NULL,
           N_("Select specified URI in parent folder."), NULL },
         { G_OPTION_REMAINING, 0, 0, G_OPTION_ARG_STRING_ARRAY, NULL, NULL, N_("[URI…]") },
 
+        /* The following are old options which have no effect anymore. We keep
+         * them around for compatibility reasons, e.g. not breaking old scripts.
+         */
+        { "browser", '\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, NULL,
+          NULL, NULL },
+        { "geometry", 'g', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_STRING, NULL,
+          NULL, NULL },
+        { "no-default-window", 'n', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, NULL,
+          NULL, NULL },
+        { "no-desktop", '\0', G_OPTION_FLAG_HIDDEN, G_OPTION_ARG_NONE, NULL,
+          NULL, NULL },
+
         { NULL }
     };
     NautilusApplicationPrivate *priv;
@@ -1213,6 +1220,59 @@ nautilus_application_withdraw_notification (NautilusApplication *self,
     g_application_withdraw_notification (G_APPLICATION (self), notification_id);
 }
 
+static void
+update_previewer_selection (NautilusApplication *self,
+                            NautilusWindow      *window)
+{
+    GtkWindow *gtk_window;
+    NautilusWindowSlot *slot;
+    NautilusView *view;
+    GList *selection;
+
+    gtk_window = gtk_application_get_active_window (GTK_APPLICATION (self));
+    if (!NAUTILUS_IS_WINDOW (gtk_window))
+    {
+        return;
+    }
+
+    if (NAUTILUS_WINDOW (gtk_window) != window)
+    {
+        return;
+    }
+
+    slot = nautilus_window_get_active_slot (window);
+    if (slot == NULL)
+    {
+        return;
+    }
+
+    view = nautilus_window_slot_get_current_view (slot);
+    if (!NAUTILUS_IS_FILES_VIEW (view))
+    {
+        return;
+    }
+
+    selection = nautilus_window_slot_get_selection (slot);
+    if (selection != NULL)
+    {
+        nautilus_files_view_preview_update (NAUTILUS_FILES_VIEW (view), selection);
+    }
+}
+
+static void
+on_application_active_window_changed (NautilusApplication *self,
+                                      GParamSpec          *pspec,
+                                      gpointer             user_data)
+{
+    GtkWindow *window;
+
+    window = gtk_application_get_active_window (GTK_APPLICATION (self));
+    if (NAUTILUS_IS_WINDOW (window))
+    {
+        update_previewer_selection (self, NAUTILUS_WINDOW (window));
+    }
+}
+
 static void
 on_application_shutdown (GApplication *application,
                          gpointer      user_data)
@@ -1293,6 +1353,7 @@ nautilus_application_startup_common (NautilusApplication *self)
 
     nautilus_profile_end (NULL);
 
+    g_signal_connect (self, "notify::active-window", G_CALLBACK (on_application_active_window_changed), NULL);
     g_signal_connect (self, "shutdown", G_CALLBACK (on_application_shutdown), NULL);
 
     g_signal_connect_object (gtk_icon_theme_get_default (),
@@ -1339,6 +1400,8 @@ nautilus_application_dbus_register (GApplication     *app,
         return FALSE;
     }
 
+    priv->previewer_selection_id = nautilus_previewer_connect_selection_event (connection);
+
     return TRUE;
 }
 
@@ -1362,6 +1425,13 @@ nautilus_application_dbus_unregister (GApplication    *app,
         nautilus_shell_search_provider_unregister (priv->search_provider);
         g_clear_object (&priv->search_provider);
     }
+
+    if (priv->previewer_selection_id != 0)
+    {
+        nautilus_previewer_disconnect_selection_event (connection,
+                                                       priv->previewer_selection_id);
+        priv->previewer_selection_id = 0;
+    }
 }
 
 static void
@@ -1489,6 +1559,13 @@ on_slot_removed (NautilusWindow      *window,
     g_signal_handlers_disconnect_by_func (slot, on_slot_location_changed, self);
 }
 
+static void
+on_active_selection_changed (NautilusWindow      *window,
+                             NautilusApplication *self)
+{
+    update_previewer_selection (self, window);
+}
+
 static void
 nautilus_application_window_added (GtkApplication *app,
                                    GtkWindow      *window)
@@ -1504,6 +1581,7 @@ nautilus_application_window_added (GtkApplication *app,
         priv->windows = g_list_prepend (priv->windows, window);
         g_signal_connect (window, "slot-added", G_CALLBACK (on_slot_added), app);
         g_signal_connect (window, "slot-removed", G_CALLBACK (on_slot_removed), app);
+        g_signal_connect (window, "active-selection-changed", G_CALLBACK (on_active_selection_changed), app);
     }
 }
 
@@ -1523,6 +1601,7 @@ nautilus_application_window_removed (GtkApplication *app,
         priv->windows = g_list_remove_all (priv->windows, window);
         g_signal_handlers_disconnect_by_func (window, on_slot_added, app);
         g_signal_handlers_disconnect_by_func (window, on_slot_removed, app);
+        g_signal_handlers_disconnect_by_func (window, on_active_selection_changed, app);
     }
 
     /* if this was the last window, close the previewer */
