@@ -252,6 +252,8 @@ void              nautilus_canvas_container_select_all                    (Nauti
 
 void              nautilus_canvas_container_select_first                  (NautilusCanvasContainer  *view);
 
+void              nautilus_canvas_container_preview_selection_event       (NautilusCanvasContainer  *view,
+                                                                           GtkDirectionType          direction);
 
 /* operations on the selection */
 GList     *       nautilus_canvas_container_get_selection                 (NautilusCanvasContainer  *view);
