@@ -22,8 +22,7 @@
  *
  */
 
-#ifndef NAUTILUS_NOTEBOOK_H
-#define NAUTILUS_NOTEBOOK_H
+#pragma once
 
 #include <glib.h>
 #include <gtk/gtk.h>
@@ -55,7 +54,8 @@ void            nautilus_notebook_next_page (NautilusNotebook *notebook);
 gboolean        nautilus_notebook_contains_slot (NautilusNotebook   *notebook,
                                                  NautilusWindowSlot *slot);
 
+gboolean        nautilus_notebook_content_area_hit (NautilusNotebook *notebook,
+                                                    gint              x,
+                                                    gint              y);
+
 G_END_DECLS
-
-#endif /* NAUTILUS_NOTEBOOK_H */
-
